<center>Hi  everyone ,
      this is a version 1.3 beta 
      under buggy so please report bugs
<marquee> Auther : SM02 , Sm02present </marquee>
this project only for edeqution perposal 

<mark>apt source only </mark>
<pre>
 apt update
 apt upgrade -y
 apt install python3-pip -y
 pip3 install --upgrade pip
 pip3 install requests
 pip3 install instaspam2

 <mark> runing commonds</mark>
 type 
 <mark>Insta-spam</mark>
     </pre>

###  Auther :  
<mark> SM02 SM01 Sm02present
### Auther : 
<mark> Simplehacker1 Community Group
### Powered by team member :
### Starting Project date : 02/02/2022
### update date  : 12/02/2022
### New Modifed : 20/02/2022
### Note : Insta-Spam changed To InstaSpam
### version : 1.0
### About  : Insagram Spam messageing  Tool for Fun 

</center>